function [upperbound, lowerbound, C, W,A] = GenConstrainMatrix(K,n,label,params)
% data constriant setting for metric learing

num_train = size(K{1},1);

EuDist = zeros(num_train,num_train);
EuMeans = zeros(3,1);
W = ones(3,1);

%% calculate Euclidean distance of original kernel data
for i = 1 : n
    temp = pdist2(K{i},K{i});

    EuMeans(i) = mean(mean(temp));
    if(i>1)
        W(i) =  EuMeans(1)/ EuMeans(i);
    end
    EuDist = EuDist +  W(i)*temp;
end

%% calculate the lowerbound and upperbound of the original Euclidean distances
EuDist= EuDist/n;

LEuDist = tril(EuDist);
LEuDist = LEuDist(:);
LEuDist(find(LEuDist==0)) = [];


meanDist = mean(LEuDist(:));
stdDist = std(LEuDist(:));
lowerbound = fix(meanDist - params.zeta*stdDist);
upperbound = fix(meanDist + params.zeta*stdDist);

%% calculate the data constraint C 
kk = 2; % default setting, kk=2 means positive : negative = 1 : 2
[index_pair] = GenConstrainPairs(label',kk);
npair = size(index_pair,1);
C = zeros(npair,4);
for i = 1 : npair
    C(i,1:2) = index_pair(i,:);
    if(mod(i,kk)==1)
        C(i,3) = 1;
        C(i,4) = lowerbound;
    else
        C(i,3) = -1;
        C(i,4) = upperbound;
    end    
end

